@@ -15,7 +15,7 @@ import numpy as np
 from .. import beta
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j00(a1, a0, nf):
     r"""
     LO-LO exact evolution integral.
@@ -38,10 +38,10 @@ def j00(a1, a0, nf):
         j00 : float
             integral
     """
-    return np.log(a1 / a0) / beta.beta(0, nf)
+    return np.log(a1 / a0) / beta.beta_qcd((2, 0), nf)
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j11_exact(a1, a0, nf):
     r"""
     NLO-NLO exact evolution integral.
@@ -65,12 +65,12 @@ def j11_exact(a1, a0, nf):
         j11 : float
             integral
     """
-    beta_1 = beta.beta(1, nf)
-    b1 = beta.b(1, nf)
-    return (1.0 / beta_1) * np.log((1.0 + a1 * b1) / (1.0 + a0 * b1))
+    beta_qcd_as3 = beta.beta_qcd((3, 0), nf)
+    b1 = beta.b_qcd((3, 0), nf)
+    return (1.0 / beta_qcd_as3) * np.log((1.0 + a1 * b1) / (1.0 + a0 * b1))
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j11_expanded(a1, a0, nf):
     r"""
     NLO-NLO expanded evolution integral.
@@ -92,10 +92,10 @@ def j11_expanded(a1, a0, nf):
         j11_exp : float
             integral
     """
-    return 1.0 / beta.beta(0, nf) * (a1 - a0)
+    return 1.0 / beta.beta_qcd((2, 0), nf) * (a1 - a0)
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j01_exact(a1, a0, nf):
     r"""
     LO-NLO exact evolution integral.
@@ -119,10 +119,10 @@ def j01_exact(a1, a0, nf):
         j11 : float
             integral
     """
-    return j00(a1, a0, nf) - beta.b(1, nf) * j11_exact(a1, a0, nf)
+    return j00(a1, a0, nf) - beta.b_qcd((3, 0), nf) * j11_exact(a1, a0, nf)
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j01_expanded(a1, a0, nf):
     r"""
     LO-NLO expanded evolution integral.
@@ -144,10 +144,10 @@ def j01_expanded(a1, a0, nf):
         j01_exp : float
             integral
     """
-    return j00(a1, a0, nf) - beta.b(1, nf) * j11_expanded(a1, a0, nf)
+    return j00(a1, a0, nf) - beta.b_qcd((3, 0), nf) * j11_expanded(a1, a0, nf)
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j22_exact(a1, a0, nf):
     r"""
     NNLO-NNLO exact evolution integral.
@@ -177,20 +177,20 @@ def j22_exact(a1, a0, nf):
         j22 : complex
             integral
     """
-    b1 = beta.b(1, nf)
-    b2 = beta.b(2, nf)
+    b1 = beta.b_qcd((3, 0), nf)
+    b2 = beta.b_qcd((4, 0), nf)
     # allow Delta to be complex for nf = 6, the final result will be real
     Delta = np.sqrt(complex(4 * b2 - b1**2))
     delta = np.arctan((b1 + 2 * a1 * b2) / Delta) - np.arctan(
         (b1 + 2 * a0 * b2) / Delta
     )
     log = np.log((1 + a1 * (b1 + b2 * a1)) / (1 + a0 * (b1 + b2 * a0)))
-    return 1 / (2 * beta.beta(2, nf)) * log - b1 / (beta.beta(2, nf)) * np.real(
-        delta / Delta
-    )
+    return 1 / (2 * beta.beta_qcd((4, 0), nf)) * log - b1 / (
+        beta.beta_qcd((4, 0), nf)
+    ) * np.real(delta / Delta)
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j12_exact(a1, a0, nf):
     r"""
     NLO-NNLO exact evolution integral.
@@ -215,17 +215,17 @@ def j12_exact(a1, a0, nf):
         j12 : complex
             integral
     """  # pylint: disable=line-too-long
-    b1 = beta.b(1, nf)
-    b2 = beta.b(2, nf)
+    b1 = beta.b_qcd((3, 0), nf)
+    b2 = beta.b_qcd((4, 0), nf)
     # allow Delta to be complex for nf = 6, the final result will be real
     Delta = np.sqrt(complex(4 * b2 - b1**2))
     delta = np.arctan((b1 + 2 * a1 * b2) / Delta) - np.arctan(
         (b1 + 2 * a0 * b2) / Delta
     )
-    return 2.0 / (beta.beta(0, nf)) * np.real(delta / Delta)
+    return 2.0 / (beta.beta_qcd((2, 0), nf)) * np.real(delta / Delta)
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j02_exact(a1, a0, nf):
     r"""
     LO-NNLO exact evolution integral.
@@ -251,12 +251,12 @@ def j02_exact(a1, a0, nf):
     """
     return (
         j00(a1, a0, nf)
-        - beta.b(1, nf) * j12_exact(a1, a0, nf)
-        - beta.b(2, nf) * j22_exact(a1, a0, nf)
+        - beta.b_qcd((3, 0), nf) * j12_exact(a1, a0, nf)
+        - beta.b_qcd((4, 0), nf) * j22_exact(a1, a0, nf)
     )
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j22_expanded(a1, a0, nf):
     r"""
     NNLO-NNLO expanded evolution integral.
@@ -278,10 +278,10 @@ def j22_expanded(a1, a0, nf):
         j22_exp : float
             integral
     """
-    return 1 / (2 * beta.beta(0, nf)) * (a1**2 - a0**2)
+    return 1 / (2 * beta.beta_qcd((2, 0), nf)) * (a1**2 - a0**2)
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j12_expanded(a1, a0, nf):
     r"""
     NLO-NNLO expanded evolution integral.
@@ -304,11 +304,11 @@ def j12_expanded(a1, a0, nf):
         j12_exp : float
             integral
     """
-    b1 = beta.b(1, nf)
-    return 1 / beta.beta(0, nf) * (a1 - a0 - b1 / 2 * (a1**2 - a0**2))
+    b1 = beta.b_qcd((3, 0), nf)
+    return 1 / beta.beta_qcd((2, 0), nf) * (a1 - a0 - b1 / 2 * (a1**2 - a0**2))
 
 
-@nb.njit("f8(f8,f8,u1)", cache=True)
+@nb.njit(cache=True)
 def j02_expanded(a1, a0, nf):
     r"""
     LO-NNLO expanded evolution integral.
@@ -333,6 +333,6 @@ def j02_expanded(a1, a0, nf):
     """
     return (
         j00(a1, a0, nf)
-        - beta.b(1, nf) * j12_expanded(a1, a0, nf)
-        - beta.b(2, nf) * j22_expanded(a1, a0, nf)
+        - beta.b_qcd((3, 0), nf) * j12_expanded(a1, a0, nf)
+        - beta.b_qcd((4, 0), nf) * j22_expanded(a1, a0, nf)
     )
