@@ -8,11 +8,10 @@ import logging
 import numpy as np
 
 from . import basis_rotation as br
-from . import interpolation
+from . import compatibility, interpolation, msbar_masses
+from .couplings import Couplings
 from .evolution_operator.grid import OperatorGrid
-from .msbar_masses import compute_msbar_mass
 from .output import Output
-from .strong_coupling import StrongCoupling
 from .thresholds import ThresholdsAtlas
 
 logger = logging.getLogger(__name__)
@@ -43,22 +42,27 @@ o888ooooood8 o888o  o888o     `Y8bood8P'
     def __init__(self, theory_card, operators_card):
         self.out = Output()
 
+        new_theory, new_operators = compatibility.update(theory_card, operators_card)
+
+        # Store inputs
+        self._theory = new_theory
+
         # setup basis grid
-        bfd = interpolation.InterpolatorDispatcher.from_dict(operators_card)
+        bfd = interpolation.InterpolatorDispatcher.from_dict(new_operators)
         self.out.update(bfd.to_dict())
         # setup the Threshold path, compute masses if necessary
         masses = None
-        if theory_card["HQ"] == "MSBAR":
-            masses = compute_msbar_mass(theory_card)
-        tc = ThresholdsAtlas.from_dict(theory_card, masses=masses)
+        if new_theory["HQ"] == "MSBAR":
+            masses = msbar_masses.compute(new_theory)
+        tc = ThresholdsAtlas.from_dict(new_theory, masses=masses)
 
         self.out["q2_ref"] = float(tc.q2_ref)
         # strong coupling
-        sc = StrongCoupling.from_dict(theory_card, masses=masses)
+        sc = Couplings.from_dict(new_theory, masses=masses)
         # setup operator grid
         self.op_grid = OperatorGrid.from_dict(
-            theory_card,
-            operators_card,
+            new_theory,
+            new_operators,
             tc,
             sc,
             bfd,
@@ -66,10 +70,10 @@ o888ooooood8 o888o  o888o     `Y8bood8P'
         self.out["inputgrid"] = bfd.xgrid_raw
         self.out["targetgrid"] = bfd.xgrid_raw
         self.post_process = dict(
-            inputgrid=operators_card.get("inputgrid", bfd.xgrid_raw),
-            targetgrid=operators_card.get("targetgrid", bfd.xgrid_raw),
-            inputbasis=operators_card.get("inputbasis"),
-            targetbasis=operators_card.get("targetbasis"),
+            inputgrid=new_operators.get("inputgrid", bfd.xgrid_raw),
+            targetgrid=new_operators.get("targetgrid", bfd.xgrid_raw),
+            inputbasis=new_operators.get("inputbasis"),
+            targetbasis=new_operators.get("targetbasis"),
         )
 
     def get_output(self):
