@@ -9,7 +9,7 @@ from sqlalchemy import Boolean, Column, Integer, Text
 
 class Operator(Base):  # pylint: disable=too-few-public-methods
     """
-    Operator cards tbale
+    Operator cards table
     """
 
     __tablename__ = "operators"
@@ -22,3 +22,4 @@ class Operator(Base):  # pylint: disable=too-few-public-methods
     ev_op_max_order = Column(Integer)
     ev_op_iterations = Column(Integer)
     Q2grid = Column(Text)
+    backward_inversion = Column(Text)
